one.grouplevel is the actual function to do the computations and is not intended to be called by the user)grouplevel(web, index="ALLBUTDD", level="both", weighted=TRUE, empty.web=FALSE,
dist="horn", CCfun=mean, logbase="e", normalise=TRUE, extinctmethod="r",
nrep=100, fcdist="euclidean", fcweighted=TRUE)groupwise can be employed on its own, it typicalTRUE. The vegdist in TRUE.fc, should the weights of the matrix be used. Defaults to TRUE, but original paper (Devoto et al. 2012) is based on FALSE.clustering_tm in clustering_tm in discrepancy for details.degreedistr for details and references.extinction slope.HL refers to the robustness of the higher level to extinctions in the lower level (and vice versa); see slope.bipartite and second.extinct for details.robustness.HL refers to the robustness of the higher level to extinctions in the lower level (and vice versa); see robustness for details. Corresponds to networklevel. Several indices have their own function as implementation: second.extinct, degreedistr, C.score and V.ratiodata(Safariland)
grouplevel(Safariland)
grouplevel(Safariland, level="lower", weighted=FALSE) #excludes degree distribution fitsRun the code above in your browser using DataLab