as.one.mode(web, fill = 0, project="full", weighted=TRUE)The lower trophic level (e.g. plants or rows) is listed first, then the higher trophic level (e.g. pollinators or columns). Hence, pollinator 2 becomes species number r+2, where r is the number of rows of the network matrix.
The benefit of this conversion is access to the wonderful R-package Social Network Analysis (betweenness, closeness, centralization, degree, kpath.census and so forth). Furthermore, gplot in that package also provides cool network depictions well worth checking out.
With respect to as.one.mode is employed in the function nodespec, which itself uses the geodist.
projecting_tm in package web2edges.data(Safariland)
image(Safariland)
image(as.one.mode(Safariland))Run the code above in your browser using DataLab