as.one.mode(web, fill = 0, project="full", weighted=TRUE)betweenness, closeness, centralization,
degree, kpath.census and so forth). Furthermore, gplot in that package also provides cool network depictions well worth checking out.
With respect to as.one.mode is employed in the function nodespec, which itself uses the geodist.data(Safariland)
image(Safariland)
image(as.one.mode(Safariland))Run the code above in your browser using DataLab